import 'package:rec_api_dart/src/entities/dto/form_data.dart';
import 'package:rec_api_dart/src/entities/transactions/currency.ent.dart';
import 'package:rec_api_dart/src/entities/transactions/vendor_data.ent.dart';
import 'package:rec_api_dart/src/helpers/checks.dart';

class PaymentData extends FormData {
  double? amount;
  String concept;
  String? address;
  String? pin;
  VendorData? vendor;
  Currency? currency;

  PaymentData({
    required this.amount,
    required this.address,
    this.concept = '',
    this.pin,
    VendorData? vendor,
    Currency? currency,
  })  : currency = currency ?? Currency.rec,
        vendor = vendor ?? VendorData();

  PaymentData.empty() : concept = '' {
    amount = null;
    address = '';
    vendor = VendorData();
    currency = Currency.rec;
  }

  PaymentData.fromUriString(String uri) : concept = '' {
    var parsedUri = Uri.parse(uri);
    currency = Currency.rec;
    amount = double.parse(parsedUri.queryParameters['amount']!);
    concept = parsedUri.queryParameters['concept'] ?? '';
    address = parsedUri.queryParameters['address'];
  }

  int get scaledAmount {
    return (amount! * 100000000).toInt();
  }

  double descaleAmount(double amount) {
    return (amount / 100000000).toDouble();
  }

  bool isComplete() {
    return amount! > 0 && concept.isNotEmpty && vendor != null;
  }

  PaymentData update(PaymentData newData) {
    currency = newData.currency;
    vendor = newData.vendor;
    amount = newData.amount;
    address = newData.address;
    concept = newData.concept;
    pin = newData.pin;

    return this;
  }

  @override
  Map<String, dynamic> toJson() {
    return {
      'amount': scaledAmount,
      'concept': concept,
      'address': address,
      'pin': pin,
    };
  }

  Map<String, dynamic> toDeeplinkJson() {
    // ignore: omit_local_variable_types
    Map<String, dynamic> map = {};

    if (amount != null) map['amount'] = '$amount';
    if (Checks.isNotEmpty(concept)) map['concept'] = concept;
    if (Checks.isNotEmpty(address)) map['address'] = address;

    return map;
  }
}
