import 'package:rec_api_dart/src/entities/account.ent.dart';
import 'package:rec_api_dart/src/entities/activity.ent.dart';

class SortDir {
  static const String asc = 'ASC';
  static const String desc = 'DESC';
}

class MapSearchData {
  bool? onMap;
  bool? onlyWithOffers;
  String? search;
  String? type;
  String? subType;
  String? sort;
  String? order;
  String? campaign;
  String? campaignCode;
  Activity? activity;
  int? limit;
  int? offset;

  MapSearchData({
    this.search = '',
    this.onMap = true,
    this.onlyWithOffers = false,
    this.type = Account.TYPE_COMPANY,
    this.subType = '',
    this.limit = 300,
    this.offset = 0,
    this.sort = 'name',
    this.order = SortDir.desc,
    this.campaign,
    this.campaignCode,
    this.activity,
  });

  void setSearch(String search) {
    this.search = search;
  }

  void setCampaign(String campaign) {
    this.campaign = campaign;
  }

  void setActivity(Activity activity) {
    this.activity = activity;
  }

  Map<String, dynamic> toJson() {
    var data = {
      'offset': '$offset',
      'limit': '$limit',
      'sort': sort,
      'order': order,
      'search': search,
      'only_with_offers': '${onlyWithOffers == true ? 1 : 0}',
      'type': type,
      'subtype': subType,
    };

    if (campaign != null && campaign!.isNotEmpty) {
      data['campaigns'] = campaign!;
    }

    if (campaignCode != null && campaignCode!.isNotEmpty) {
      data['campaign_code'] = campaignCode!;
    }

    if (activity != null) {
      data['activity_id'] = activity!.id!;
    }

    return data;
  }

  MapSearchData copyWith({
    String? search,
    bool? onMap,
    bool? onlyWithOffers,
    String? type,
    String? subType,
    String? sort,
    String? order,
    String? campaign,
    String? campaignCode,
    Activity? activity,
    int? limit,
    int? offset,
  }) {
    return MapSearchData(
      search: search ?? this.search,
      onMap: onMap ?? this.onMap,
      onlyWithOffers: onlyWithOffers ?? this.onlyWithOffers,
      type: type ?? this.type,
      campaign: campaign ?? this.campaign,
      campaignCode: campaignCode ?? this.campaignCode,
      subType: subType ?? this.subType,
      limit: limit ?? this.limit,
      offset: offset ?? this.offset,
      sort: sort ?? this.sort,
      order: order ?? this.order,
      activity: activity ?? this.activity,
    );
  }

  MapSearchData copyFrom(MapSearchData data) {
    return MapSearchData(
      search: data.search ?? search,
      onMap: data.onMap ?? onMap,
      onlyWithOffers: data.onlyWithOffers ?? onlyWithOffers,
      type: data.type ?? type,
      campaign: data.campaign ?? campaign,
      campaignCode: data.campaignCode ?? campaignCode,
      subType: data.subType ?? subType,
      limit: data.limit ?? limit,
      offset: data.offset ?? offset,
      sort: data.sort ?? sort,
      order: data.order ?? order,
      activity: data.activity,
    );
  }
}
