import 'package:http/http.dart';
import 'package:rec_api_dart/src/api_paths.dart';
import 'package:rec_api_dart/src/entities/activity.ent.dart';
import 'package:rec_api_dart/src/env.base.dart';
import 'package:rec_api_dart/src/interceptors/user_token_interceptor.dart';
import 'package:rec_api_dart/src/interfaces/api_list_response.dart';
import 'package:rec_api_dart/src/services/base_service.dart';

class ActivitiesService extends ServiceBase {
  ActivitiesService({required EnvBase env, Client? client})
      : super(
          env: env,
          client: client,
          interceptors: [UserTokenInterceptor()],
        );

  /// List all [Activities] for the authenticated user
  Future<ApiListResponse<Activity>> list() {
    final uri = ApiPaths.activities.withQueryParams({
      'limit': '100',
    }).toUri(env);

    return this.get(uri).then(_mapActivities);
  }

  ApiListResponse<Activity> _mapActivities(
    Map<String, dynamic> data,
  ) {
    return ApiListResponse.fromJson(
      {'elements': data['data']},
      mapper: (el) => Activity.fromJson(el),
    );
  }
}
