import 'package:http/http.dart';
import 'package:rec_api_dart/src/api_paths.dart';
import 'package:rec_api_dart/src/entities/campaign.ent.dart';
import 'package:rec_api_dart/src/env.base.dart';
import 'package:rec_api_dart/src/interceptors/user_token_interceptor.dart';
import 'package:rec_api_dart/src/interfaces/api_list_response.dart';
import 'package:rec_api_dart/src/services/base_service.dart';

/// This service is in charge of all requests related to [Campaigns]
///
/// * **Authentication Required** - the user must be authenticated
class CampaignsService extends ServiceBase {
  CampaignsService({required EnvBase env, Client? client})
      : super(
          env: env,
          client: client,
          interceptors: [UserTokenInterceptor()],
        );

  /// List all [DocumentKinds]
  Future<Campaign> getOne(String id) {
    final uri = ApiPaths.campaigns.append(id).toUri(env);

    return this.get(uri).then((res) {
      return Campaign.fromJson(res['data']);
    });
  }

  /// List all [Campaign] for the authenticated user
  Future<ApiListResponse<Campaign?>> list() {
    final uri = ApiPaths.campaigns.toUri(env);

    return this.get(uri).then(_mapCampaigns);
  }

  ApiListResponse<Campaign?> _mapCampaigns(
    Map<String, dynamic> resp,
  ) {
    return ApiListResponse.fromJson(
      resp['data'],
      mapper: (el) => Campaign.fromJson(el),
    );
  }
}
