import 'dart:async';

import 'package:dio/dio.dart' as dio;
import 'package:http/http.dart';
import 'package:rec_api_dart/src/api_error.dart';
import 'package:rec_api_dart/src/api_paths.dart';
import 'package:rec_api_dart/src/auth.dart';
import 'package:rec_api_dart/src/env.base.dart';
import 'package:rec_api_dart/src/helpers/checks.dart';
import 'package:rec_api_dart/src/interceptors/user_token_interceptor.dart';
import 'package:rec_api_dart/src/services/base_service.dart';

class ImageUploaderService extends ServiceBase {
  final dio.Dio _dio = dio.Dio();

  ImageUploaderService({required EnvBase env, Client? client})
      : super(
          env: env,
          client: client,
          interceptors: [UserTokenInterceptor()],
        );

  Future uploadImage(var imagePath) async {
    var token = await Auth.getAccessToken();
    var formData = dio.FormData.fromMap({
      'file': await dio.MultipartFile.fromFile(imagePath),
    });
    var uri = ApiPaths.uploadFile.toUri(env).toString();

    return _dio
        .post(
          uri,
          data: formData,
          options: dio.Options(
            headers: {
              'Authorization': 'Bearer $token',
            },
          ),
        )
        .then(_onDioResponse);
  }

  FutureOr<Map<String, dynamic>> _onDioResponse(dio.Response response) {
    if (response.statusCode! >= 400) {
      return Future.error(ApiError.fromDioResponse(response));
    }

    return Future.value(
      Checks.isNotEmpty(response.data) ? response.data : {},
    );
  }
}
