import 'package:http/http.dart';
import 'package:rec_api_dart/src/api_paths.dart';
import 'package:rec_api_dart/src/entities/dto/create_offer_data.dart';
import 'package:rec_api_dart/src/entities/dto/update_offer_data.dart';
import 'package:rec_api_dart/src/entities/offer.ent.dart';
import 'package:rec_api_dart/src/env.base.dart';
import 'package:rec_api_dart/src/interceptors/user_token_interceptor.dart';
import 'package:rec_api_dart/src/interfaces/api_list_response.dart';
import 'package:rec_api_dart/src/services/base_service.dart';

/// This service is in charge of all requests related to [Offers]
/// Like listing, posting, updating, etc...
///
/// * **Authentication Required** - the user must be authenticated
class OffersService extends ServiceBase {
  OffersService({required EnvBase env, Client? client})
      : super(
          env: env,
          client: client,
          interceptors: [UserTokenInterceptor()],
        );

  /// List all [Offer] for the authenticated user
  Future<ApiListResponse<Offer>> list() {
    final uri = ApiPaths.offers.toUri(env);

    return this.get(uri).then(_mapOffers);
  }

  /// List all [Offer] for an account
  Future<ApiListResponse<Offer>> listFor({required String accountId}) {
    final uri = ApiPaths.offers.toUri(env);

    return this.get(uri).then(_mapOffers);
  }

  /// Creates an offer linekd to the authenticated user's account.
  Future createOffer(CreateOfferData data) {
    final uri = ApiPaths.offers.toUri(env);

    return this.post(uri, data.toJson());
  }

  /// Update an offer instance
  Future updateOffer(String offerId, UpdateOfferData data) {
    final uri = ApiPaths.offers.append(offerId).toUri(env);

    return this.put(uri, data.toJson());
  }

  /// Delete an offer instance
  Future deleteOffer(String? offerId) {
    final uri = ApiPaths.offers.append(offerId).toUri(env);

    return this.delete(uri);
  }

  ApiListResponse<Offer> _mapOffers(
    Map<String, dynamic> data,
  ) {
    return ApiListResponse.fromJson(
      {'elements': data['data']},
      mapper: (el) => Offer.fromJson(el),
    );
  }
}
