import 'package:http/http.dart';
import 'package:rec_api_dart/src/api_paths.dart';
import 'package:rec_api_dart/src/auth.dart';
import 'package:rec_api_dart/src/entities/dto/login_data.dart';
import 'package:rec_api_dart/src/env.base.dart';
import 'package:rec_api_dart/src/grant_types.dart';
import 'package:rec_api_dart/src/services/base_service.dart';

class LoginService extends ServiceBase {
  LoginService({required EnvBase env, Client? client})
      : super(
          env: env,
          client: client,
        );

  Future login(LoginData data, {String platform = 'rec-admin'}) async {
    var body = {
      ...data.toJson(),
      'grant_type': GrantTypes.password,
      'client_id': env.CLIENT_ID,
      'client_secret': env.CLIENT_SECRET,
      'platform': platform,
    };

    return this.post(ApiPaths.token.toUri(env), body).then(saveToken);
  }

  Future refreshToken(String? refreshToken) async {
    var body = {
      'grant_type': GrantTypes.refreshToken,
      'client_id': env.CLIENT_ID,
      'client_secret': env.CLIENT_SECRET,
      'refresh_token': refreshToken,
    };

    return this.post(ApiPaths.refreshToken.toUri(env), body).then(saveToken);
  }

  static Future saveToken(value) async {
    await Auth.saveTokenData(value);

    return value;
  }
}
