import 'package:http/http.dart';
import 'package:rec_api_dart/src/api_paths.dart';
import 'package:rec_api_dart/src/entities/dto/change_password_data.dart';
import 'package:rec_api_dart/src/entities/dto/change_pin_data.dart';
import 'package:rec_api_dart/src/env.base.dart';
import 'package:rec_api_dart/src/interceptors/user_token_interceptor.dart';
import 'package:rec_api_dart/src/services/base_service.dart';

class SecurityService extends ServiceBase {
  SecurityService({required EnvBase env, Client? client})
      : super(
          env: env,
          client: client,
          interceptors: [
            UserTokenInterceptor(),
          ],
        );

  /// This requests a pin change for the current authenticated user
  /// When the user has the pin is already set in the user
  Future<dynamic> changePin(ChangePinData data) {
    var path = ApiPaths.changePin.toUri(env);

    return this.put(
      path,
      data.toJson(),
    );
  }

  /// This requests to create/set the pin initially for the current authenticated user
  /// When the user has no pin set already
  Future<dynamic> createPin({
    required String pin,
    required String repin,
    required String smscode,
  }) {
    var path = ApiPaths.changePin.toUri(env);

    return this.put(
      path,
      {
        'pin': pin,
        'repin': repin,
        'sms_code': smscode,
      },
    );
  }

  /// This requests a passwrod change for the current authenticated user
  Future<dynamic> changePassword(ChangePasswordData data) {
    var path = ApiPaths.changePassword.toUri(env);

    return this.put(
      path,
      data.toJson(),
    );
  }
}
