import 'package:http/http.dart';
import 'package:rec_api_dart/src/api_paths.dart';
import 'package:rec_api_dart/src/env.base.dart';
import 'package:rec_api_dart/src/interceptors/user_token_interceptor.dart';

import 'base_service.dart';

/// Service to manage user-level sms codes
class UserSmsService extends ServiceBase {
  static const String SMS_CHANGE_PIN = 'change-pin';
  static const String SMS_CHANGE_PASSWORD = 'change-password';
  static final List<String> SMS_TYPES = [SMS_CHANGE_PIN, SMS_CHANGE_PASSWORD];

  UserSmsService({required EnvBase env, Client? client})
      : super(
          env: env,
          client: client,
          interceptors: [
            UserTokenInterceptor(),
          ],
        );

  /// Request to send and SMS for a specific [type]
  /// See [UserSmsService.SMS_TYPES] for all available types
  Future sendSms({
    Map<String, String> data = const {},
    String? type,
  }) {
    // Checks if the type if valid
    assert(
      SMS_TYPES.contains(type),
      'Type must be one of ${SMS_TYPES.join(', ')}',
    );

    var pathWithParams = ApiPaths.sendUserSmsCode.append(type).toUri(env);

    return this.post(pathWithParams, data);
  }

  /// Request to send an SMS code to change pin
  Future sendChangePinSms() {
    return sendSms(type: SMS_CHANGE_PIN);
  }

  /// Request to send an SMS code to change password
  Future sendChangePasswordSms() {
    return sendSms(type: SMS_CHANGE_PASSWORD);
  }
}
