import 'package:http/http.dart';
import 'package:rec_api_dart/src/api_paths.dart';
import 'package:rec_api_dart/src/entities/user.ent.dart';
import 'package:rec_api_dart/src/env.base.dart';
import 'package:rec_api_dart/src/interceptors/user_token_interceptor.dart';
import 'package:rec_api_dart/src/services/base_service.dart';

class UsersService extends ServiceBase {
  UsersService({required EnvBase env, Client? client})
      : super(
          env: env,
          client: client,
          interceptors: [
            UserTokenInterceptor(),
          ],
        );

  Future<User> getUser() {
    final uri = ApiPaths.currentUserAccount.toUri(env);

    return this.get(uri).then(_mapToUser);
  }

  Future<Map<String, dynamic>> updateUser(Map<dynamic, dynamic> data) {
    final uri = ApiPaths.currentUserAccount.toUri(env);

    return this.put(uri, data);
  }

  Future<Map<String, dynamic>> updateKycUser(
      num? kycId, Map<dynamic, dynamic> data) {
    final uri = ApiPaths.currentUserKyc.append(kycId.toString()).toUri(env);

    return this.put(uri, data);
  }

  Future acceptCampaignTos(String code) {
    final uri = ApiPaths.acceptTos.toUri(env);

    return this.put(uri, {
      'campaign_code': code,
    });
  }

  Future updateLtabTos(bool accepted) {
    final uri = ApiPaths.currentUserAccount.toUri(env);

    return this.put(uri, {
      'private_tos_campaign': accepted,
    });
  }

  Future<Map<String, dynamic>> changeLanguage(String? locale) {
    final uri = ApiPaths.currentUserAccount.toUri(env);

    return this.put(uri, {'locale': locale});
  }

  Future<Map<String, dynamic>> selectMainAccount(String? accountId) {
    final uri = ApiPaths.changeAccount.toUri(env);

    return this.put(uri, {'group_id': accountId});
  }

  User _mapToUser(Map<String, dynamic> resp) {
    return User.fromJson(resp['data']);
  }
}
