import 'package:http/http.dart';
import 'package:rec_api_dart/src/api_paths.dart';
import 'package:rec_api_dart/src/entities/dto/recharge_data.dart';
import 'package:rec_api_dart/src/entities/transactions/recharge_result.dart';
import 'package:rec_api_dart/src/env.base.dart';
import 'package:rec_api_dart/src/interceptors/user_token_interceptor.dart';
import 'package:rec_api_dart/src/services/base_service.dart';

/// This service handles REC recharges
///
/// * **Authentication Required** - the user must be authenticated
class RechargeService extends ServiceBase {
  RechargeService({required EnvBase env, Client? client})
      : super(
          env: env,
          client: client,
          interceptors: [UserTokenInterceptor()],
        );

  Future<RechargeResult> recharge(RechargeData data) {
    final uri = ApiPaths.rechargeRecs.toUri(env);
    final body = data.toJson();

    return this.post(uri, body).then(_onResponse);
  }

  RechargeResult _onResponse(Map<String, dynamic> data) {
    return RechargeResult.fromJson(data);
  }
}
